@@ -92,6 +92,8 @@ class _OSLCOperations_Mixin:
                         ,isnotnulls=None, enhanced=True, show_progress=True
                         ,show_info=False, verbose=False, maxresults=None, delaybetweenpages=0.0
                         , pagesize=200
+                        ,resolvenames=True
+                        ,totalize=False
                      ):
         if searchterms and querystring:
             logger.info( f"{searchterms=}" )
@@ -178,7 +180,7 @@ class _OSLCOperations_Mixin:
         if show_progress:
             total = len(originalresults.items())
             pbar = tqdm.tqdm(initial=0, total=total,smoothing=1,unit=" results",desc="Processing       ")
-
+        totalizecolumns = []
         # convert uris to human-friendly names
         for kuri, v in originalresults.items():
             logger.info( f"post-processing result {kuri} {v}" )
@@ -187,11 +189,17 @@ class _OSLCOperations_Mixin:
                 logger.info( f"{kattr=} {vattr=}" )
                 # first try to convert the value to a name
                 if isinstance(vattr, list):
+                    if totalize and kattr not in totalizecolumns:
+                        totalizecolumns.append(kattr)
+                        print( f"Going to totalize {kattr}" )
                     remappedvalue = []
                     for lv in vattr:
-                        remappedvalue.append(self.resolve_uri_to_name(lv))
+                        if resolvenames:
+                            remappedvalue.append(self.resolve_uri_to_name(lv))
+                        else:
+                            remappedvalue.append(lv)
                 else:
-                    remappedvalue = self.resolve_uri_to_name(vattr)
+                    remappedvalue = self.resolve_uri_to_name(vattr) if resolvenames else vattr
                 # then check the attribute itself for one of the mappings we created while parsing the querystring to turn it into an oslc query
                 if kattr in uri_to_name_mapping:
                     # this name was locally mapped
@@ -199,8 +207,15 @@ class _OSLCOperations_Mixin:
                 else:
                     # try to map back to a name
                     if kattr not in remappednames:
-                        remappedname = self.resolve_uri_to_name(kattr)
+                        remappedname = self.resolve_uri_to_name(kattr) if resolvenames else kattr
                         remappednames[kattr] = remappedname
+                        
+                        if kattr in totalizecolumns:
+                            print( f"Totalizer replacing katter {kattr} with {remappedname}" )
+                            # remove the old name, add the new name
+                            totalizecolumns.remove(kattr)
+                            totalizecolumns.append(remappedname)
+                        
                     if remappednames[kattr] is not None:
                         v1[remappednames[kattr]] = remappedvalue
                     else:
@@ -210,12 +225,29 @@ class _OSLCOperations_Mixin:
 
             if show_progress:
                 pbar.update(1)
-
+                
         # if showing progress and pbar has been created (after the first set of results if paged)
         if show_progress and pbar is not None:
             # close off the progress bar
             pbar.close()
             print( "Processing completed" )
+            
+        # fixup the totalized columns to ensure all entries are lengths even if empty or one (non-list) entry
+        if totalize:
+            for k,v in mappedresult.items():
+                for tot in totalizecolumns:
+                    print( f"Totalizing {tot=}" )
+                    vattr = v.get(tot)
+                    if not vattr:
+                        newv = 0
+                        print( f"Replacing {vattr} with 0" )
+                    elif isinstance(vattr, list):
+                        newv = len(vattr)
+                        print( f"Replacing list {len(vattr)} with {newv=}" )
+                    else:
+                        newv = 1
+                        print( f"Replacing {vattr} with {newv=}" )
+                    v[tot]=newv
 
         if isnulls or isnotnulls:
             logger.debug( f"{isnulls=} {isnotnulls=}" )
@@ -374,6 +406,7 @@ class _OSLCOperations_Mixin:
             query_params1 = self.hooks[0](query_params)
         else:
              query_params1 = query_params
+
         results = self._execute_vanilla_oslc_query(querycapabilityuri,query_params1, select=select, prefixes=prefixes, show_progress=show_progress, verbose=verbose, maxresults=maxresults, delaybetweenpages=delaybetweenpages, pagesize=pagesize, intent=intent)
         return results
 
@@ -407,7 +440,7 @@ class _OSLCOperations_Mixin:
                 if operator == "scope":
                     # handle nested series of whereterms recursively
                     scopedterm = self._get_query_clauses(value, prefixmap)
-                    clauses.append(f'{tag} {{ {scopedterm} }}')
+                    clauses.append(f'{tag}{{{scopedterm}}}')    # note there are no space chars allowed by the OSLC Query sytax!
                 elif operator == "in":
                     inlist = []
                     for val in value:
@@ -494,6 +527,7 @@ class _OSLCOperations_Mixin:
             query_params['oslc.paging'] = 'true'
             query_params['oslc.pageSize'] = str(pagesize) if maxresults is None or ( pagesize>0 and pagesize<maxresults ) else str(maxresults)
 
+
         logger.debug(f"execute_query {query_params} {select}")
         base_uri = querycapabilityuri
         logger.info( f"The base OSLC Query URL is {base_uri}" )
@@ -507,7 +541,9 @@ class _OSLCOperations_Mixin:
         url_parts[4] = ""
         url_parts[5] = ""
         # reconstruct just the base scheme:hostname
+        # inisists on using + instead of %20!
         query_url = urllib.parse.urlunparse(url_parts)
+        
         logger.info( f"The full OSLC Query URL is {query_url}" )
 
         # in case of paged results, always prepare to collect a list of results
@@ -516,11 +552,11 @@ class _OSLCOperations_Mixin:
         params.update(query)
         logger.info( f"The parameters for this query are {params}" )
 
-        fullurl = f"{query_url}?{urllib.parse.urlencode( params, quote_via=urllib.parse.quote, safe='')}"
+        fullurl = f"{query_url}?{urllib.parse.urlencode( params, quote_via=urllib.parse.quote, safe='/')}"
         if verbose:
             print( f"Full query URL is {fullurl}" )
 #        print( f"Full query URL is {fullurl}" )
-
+#        burp
         # retrieve all pages of results - they will be processed later
         total = 1
         page = 0
@@ -554,7 +590,7 @@ class _OSLCOperations_Mixin:
                 # no more results to get
                 break
 
-            # no parameters should be sent on following pages
+            # no parameters should be sent on following pages, they are present in the href link to next page!
             params = None
 
             # work out the url for the next page
